@@ -1,9 +1,6 @@
 <?php
 /**
- * This class provides an API for various compression techniques that can be
- * used by Horde applications.
- *
- * Copyright 2003-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2003-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -13,6 +10,16 @@
  * @license  http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package  Compress
  */
+
+/**
+ * This class provides an API for various compression techniques that can be
+ * used by Horde applications.
+ *
+ * @author   Michael Slusarz <slusarz@horde.org>
+ * @category Horde
+ * @license  http://www.horde.org/licenses/lgpl21 LGPL 2.1
+ * @package  Compress
+ */
 class Horde_Compress
 {
     /**
@@ -27,10 +34,10 @@ class Horde_Compress
      * @return Horde_Compress_Base  The newly created concrete instance.
      * @throws Horde_Compress_Exception
      */
-    static public function factory($driver, $params = null)
+    public static function factory($driver, $params = null)
     {
         /* Base drivers (in Compress/ directory). */
-        $class = __CLASS__ . '_' . ucfirst($driver);
+        $class = __CLASS__ . '_' . Horde_String::ucfirst($driver);
         if (@class_exists($class)) {
             return new $class($params);
         }
