@@ -2,7 +2,7 @@
 /**
  * The base class that all compress drivers should extend.
  *
- * Copyright 2011-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2011-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -28,6 +28,22 @@ class Horde_Compress_Base
      */
     public $canDecompress = false;
 
+    /**
+     * Logger
+     *
+     * @var Horde_Log_Logger
+     */
+    protected $_logger;
+
+    public function __construct($options = array())
+    {
+        if (!empty($options['logger'])) {
+            $this->_logger = $options['logger'];
+        } else {
+            $this->_logger = new Horde_Support_Stub();
+        }
+    }
+
     /**
      * Compress the data.
      *
